import { inject, openBlock, createBlock, createVNode, defineComponent, ref, watchEffect, createTextVNode, toDisplayString, resolveComponent, createCommentVNode, Fragment, renderList, pushScopeId, popScopeId, renderSlot, withScopeId, computed, reactive } from 'vue';
import { matchSorter } from 'match-sorter';
import { inject as inject$1 } from 'vue-demi';

var Position;
(function (Position) {
    Position["TR"] = "top-right";
    Position["TL"] = "top-left";
    Position["BR"] = "bottom-right";
    Position["BL"] = "bottom-left";
})(Position || (Position = {}));
var QueryState;
(function (QueryState) {
    QueryState[QueryState["Fetching"] = 0] = "Fetching";
    QueryState[QueryState["Fresh"] = 1] = "Fresh";
    QueryState[QueryState["Stale"] = 2] = "Stale";
    QueryState[QueryState["Inactive"] = 3] = "Inactive";
})(QueryState || (QueryState = {}));
const QueryStateLabel = {
    [QueryState.Fetching]: "fetching",
    [QueryState.Fresh]: "fresh",
    [QueryState.Stale]: "stale",
    [QueryState.Inactive]: "inactive",
};
function getQueryState(query) {
    if (query.isFetching()) {
        return QueryState.Fetching;
    }
    if (!query.observers.length) {
        return QueryState.Inactive;
    }
    if (query.isStale()) {
        return QueryState.Stale;
    }
    return QueryState.Fresh;
}
function getQueryStatusColor(query, theme) {
    const queryState = getQueryState(query);
    if (queryState === QueryState.Fetching) {
        return theme.active;
    }
    if (queryState === QueryState.Stale) {
        return theme.warning;
    }
    if (queryState === QueryState.Inactive) {
        return theme.gray;
    }
    return theme.success;
}
function getQueryStatusLabel(query) {
    return QueryStateLabel[getQueryState(query)];
}
const getStatusRank = (query) => {
    return getQueryState(query);
};
const queryHashSort = (a, b) => (a.queryHash > b.queryHash ? 1 : -1);
const dateSort = (a, b) => a.state.dataUpdatedAt < b.state.dataUpdatedAt ? 1 : -1;
const statusAndDateSort = (a, b) => getStatusRank(a) === getStatusRank(b)
    ? dateSort(a, b)
    : getStatusRank(a) > getStatusRank(b)
        ? 1
        : -1;
const sortFns = {
    "Status > Last Updated": statusAndDateSort,
    "Query Hash": queryHashSort,
    "Last Updated": dateSort,
};

const theme = {
    background: "#0b1521",
    backgroundAlt: "#132337",
    foreground: "white",
    gray: "#3f4e60",
    grayAlt: "#222e3e",
    inputBackgroundColor: "#fff",
    inputTextColor: "#000",
    success: "#00ab52",
    danger: "#ff0085",
    active: "#006bff",
    warning: "#ffb200",
};
const VUE_QUERY_DEVTOOLS_THEME = "VUE_QUERY_DEVTOOLS_THEME";
function useTheme() {
    return inject(VUE_QUERY_DEVTOOLS_THEME, theme);
}

const VUE_QUERY_CLIENT = "VUE_QUERY_CLIENT";
function useQueryClient() {
    const queryClient = inject$1(VUE_QUERY_CLIENT);
    if (!queryClient) {
        throw new Error("No queryClient found in Vue context, use 'app.provide(VUE_QUERY_CLIENT, new QueryClient());' to set one in root component.");
    }
    return queryClient;
}

const _hoisted_1$8 = {
  xmlns: "http://www.w3.org/2000/svg",
  width: "40",
  height: "40",
  viewBox: "0 0 190 190"
};
const _hoisted_2$3 = /*#__PURE__*/createVNode("g", { fill: "none" }, [
  /*#__PURE__*/createVNode("path", {
    fill: "#002C4B",
    d: "M150.276 61.344c3.093-14.981 3.756-26.471 1.757-34.815-1.189-4.962-3.362-9.01-6.668-11.93-3.49-3.084-7.901-4.597-12.858-4.597-8.178 0-16.775 3.725-25.963 10.802-3.747 2.887-7.636 6.366-11.676 10.44a8.743 8.743 0 00-1.09-1.163C82.36 19.915 72.746 13.599 64.523 11.164c-4.89-1.448-9.48-1.586-13.66-.181-4.414 1.483-7.93 4.55-10.41 8.845-4.094 7.089-5.174 16.403-3.648 27.904.623 4.688 1.686 9.794 3.189 15.327a8.725 8.725 0 00-1.698.38c-14.489 4.797-24.749 9.955-30.96 15.85-3.696 3.506-6.109 7.41-6.981 11.733-.921 4.562-.023 9.137 2.454 13.43 4.087 7.078 11.6 12.66 22.304 17.082 4.298 1.776 9.161 3.384 14.595 4.83a8.735 8.735 0 00-.57 1.776c-3.092 14.98-3.756 26.47-1.756 34.814 1.188 4.962 3.362 9.01 6.667 11.93 3.49 3.084 7.902 4.597 12.86 4.597 8.177 0 16.774-3.725 25.962-10.802 3.787-2.917 7.72-6.44 11.805-10.57.42.656.936 1.267 1.546 1.81 11.42 10.166 21.034 16.482 29.257 18.917 4.89 1.448 9.48 1.586 13.66.181 4.414-1.483 7.93-4.55 10.41-8.845 4.094-7.089 5.174-16.403 3.648-27.904-.645-4.857-1.764-10.164-3.354-15.929a8.715 8.715 0 001.863-.398c14.489-4.797 24.749-9.955 30.96-15.85 3.696-3.506 6.109-7.41 6.981-11.733.921-4.562.023-9.137-2.454-13.43-4.087-7.078-11.6-12.66-22.304-17.082-4.427-1.828-9.452-3.48-15.082-4.959.2-.49.36-1.006.47-1.543z"
  }),
  /*#__PURE__*/createVNode("path", {
    fill: "#FFD94C",
    d: "M80.397 64h29.211a5 5 0 014.337 2.512l14.632 25.5a5 5 0 010 4.976l-14.632 25.5a5 5 0 01-4.337 2.512H80.397a5 5 0 01-4.337-2.512l-14.632-25.5a5 5 0 010-4.976l14.632-25.5A5 5 0 0180.397 64zm25.59 6.277a5 5 0 014.339 2.513l11.017 19.224a5 5 0 010 4.972l-11.017 19.224a5 5 0 01-4.338 2.513h-21.97a5 5 0 01-4.339-2.513L68.662 96.986a5 5 0 010-4.972L79.679 72.79a5 5 0 014.338-2.513h21.97zm-3.906 6.864H87.924a5 5 0 00-4.335 2.51l-7.1 12.358a5 5 0 000 4.982l7.1 12.358a5 5 0 004.335 2.51h14.157a5 5 0 004.335-2.51l7.1-12.358a5 5 0 000-4.982l-7.1-12.358a5 5 0 00-4.335-2.51zm-3.762 6.571a5 5 0 014.334 2.506l3.33 5.788a5 5 0 010 4.988l-3.33 5.788a5 5 0 01-4.334 2.506h-6.633a5 5 0 01-4.334-2.506l-3.33-5.788a5 5 0 010-4.988l3.33-5.788a5 5 0 014.334-2.506h6.633zm-3.315 6.473a4.313 4.313 0 10-.003 8.63 4.313 4.313 0 10.003-8.63zM60 94.5h7.768"
  }),
  /*#__PURE__*/createVNode("path", {
    fill: "#FF4154",
    d: "M54.86 108.358a2.713 2.713 0 013.718 1.041l.475.845a269.421 269.421 0 0011.888 19.191c4.867 7.15 10.34 14.39 16.421 21.716a2.776 2.776 0 01-.296 3.847l-.612.537c-20.107 17.568-33.176 21.078-39.206 10.527-5.898-10.32-3.764-29.08 6.403-56.28a2.748 2.748 0 011.21-1.424zm85.674 20.684a2.708 2.708 0 013.126 2.152l.153.792c4.97 26.01 1.47 39.014-10.497 39.014-11.706 0-26.607-11.091-44.703-33.273a2.725 2.725 0 01-.613-1.745 2.712 2.712 0 012.73-2.694l.955.007c7.62.041 15.03-.223 22.226-.794 8.498-.673 17.373-1.826 26.623-3.46zm6.875-55.23c.523-1.41 2.1-2.149 3.546-1.663l.788.266c25.84 8.803 35.66 18.477 29.455 29.022-6.068 10.314-23.714 17.823-52.936 22.527a2.852 2.852 0 01-1.88-.345 2.726 2.726 0 01-.993-3.772l.5-.837c3.988-6.694 7.592-13.356 10.813-19.986 3.803-7.83 7.372-16.233 10.707-25.212zm-85.67-7.776a2.852 2.852 0 011.878.345 2.726 2.726 0 01.994 3.772l-.5.837c-3.988 6.694-7.592 13.356-10.813 19.986-3.803 7.83-7.372 16.233-10.707 25.212-.523 1.41-2.1 2.149-3.546 1.663l-.788-.266c-25.84-8.803-35.66-18.477-29.455-29.022C14.87 78.25 32.516 70.74 61.738 66.036zm41.807-31.57c20.107-17.57 33.176-21.079 39.206-10.528 5.898 10.32 3.764 29.08-6.403 56.28a2.748 2.748 0 01-1.21 1.424 2.713 2.713 0 01-3.717-1.041l-.475-.845a269.421 269.421 0 00-11.888-19.191c-4.867-7.15-10.34-14.39-16.421-21.716a2.776 2.776 0 01.296-3.847zM57.684 18c11.706 0 26.607 11.091 44.703 33.273.402.492.618 1.11.613 1.745a2.712 2.712 0 01-2.73 2.694l-.955-.007c-7.62-.041-15.03.223-22.226.794-8.498.673-17.373 1.826-26.623 3.46a2.708 2.708 0 01-3.126-2.153l-.153-.792C42.217 31.004 45.717 18 57.684 18z"
  })
], -1 /* HOISTED */);

function render$c(_ctx, _cache) {
  return (openBlock(), createBlock("svg", _hoisted_1$8, [
    _hoisted_2$3
  ]))
}

const script$c = {};


script$c.render = render$c;
script$c.__file = "src/devtools/components/Logo.vue";

var script$b = defineComponent({
    name: "ExplorerTree",
    props: {
        label: {},
        defaultExpanded: {
            type: Object,
        },
        pageSize: {
            type: Number,
            default: 100,
        },
        depth: {
            type: Number,
            default: 0,
        },
        value: {},
    },
    setup(props) {
        const theme = useTheme();
        const expanded = ref(props.defaultExpanded);
        const expandedPages = ref([]);
        const path = ref([]);
        const type = ref(typeof props.value);
        const subEntries = ref([]);
        const subEntryPages = ref([]);
        const toggle = (set) => {
            expanded.value = typeof set !== "undefined" ? set : !expanded.value;
        };
        const makeProperty = (sub) => {
            const newPath = path.value.concat(sub.label);
            let subDefaultExpanded = false;
            if (typeof props.defaultExpanded === "boolean") {
                if (props.defaultExpanded === true) {
                    subDefaultExpanded = { [sub.label]: true };
                }
            }
            else if (props.defaultExpanded) {
                subDefaultExpanded = props.defaultExpanded[sub.label];
            }
            return Object.assign(Object.assign({}, sub), { path: newPath, depth: props.depth + 1, defaultExpanded: subDefaultExpanded });
        };
        watchEffect(() => {
            if (Array.isArray(props.value)) {
                type.value = "array";
                subEntries.value = props.value.map((d, i) => {
                    return makeProperty({
                        label: i,
                        value: d,
                    });
                });
            }
            else if (props.value !== null &&
                typeof props.value === "object" &&
                typeof props.value[Symbol.iterator] === "function") {
                type.value = "Iterable";
                subEntries.value = Array.from(props.value, (val, i) => makeProperty({
                    label: i,
                    value: val,
                }));
            }
            else if (typeof props.value === "object" && props.value !== null) {
                type.value = "object";
                subEntries.value = Object.entries(props.value).map(([label, value]) => makeProperty({
                    label,
                    value,
                }));
            }
            if (subEntries.value) {
                let i = 0;
                while (i < subEntries.value.length) {
                    subEntryPages.value.push(subEntries.value.slice(i, i + props.pageSize));
                    i = i + props.pageSize;
                }
            }
        });
        const setExpandedPages = (index) => {
            if (expandedPages.value.includes(index)) {
                expandedPages.value = expandedPages.value.filter((d) => d !== index);
            }
            else {
                expandedPages.value = [...expandedPages.value, index];
            }
        };
        return {
            subEntryPages,
            toggle,
            expanded,
            subEntries,
            type,
            expandedPages,
            setExpandedPages,
            theme,
        };
    },
});

const _hoisted_1$7 = {
  key: 3,
  style: { cursor: 'pointer', color: 'white' }
};
const _hoisted_2$2 = /*#__PURE__*/createTextVNode(/*#__PURE__*/toDisplayString(" ") + " ");

function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_ExplorerTree = resolveComponent("ExplorerTree");

  return (openBlock(), createBlock("div", {
    style: {
      fontFamily: 'Menlo, monospace',
      fontSize: '0.9rem',
      lineHeight: '1.7',
      outline: 'none',
      wordBreak: 'break-word',
    },
    key: _ctx.label
  }, [
    (_ctx.subEntryPages?.length)
      ? (openBlock(), createBlock("span", {
          key: 0,
          style: { cursor: 'pointer', color: 'white' },
          onClick: _cache[1] || (_cache[1] = () => _ctx.toggle())
        }, [
          createVNode("span", {
            style: {
          display: 'inline-block',
          transition: 'all .1s ease',
          transform: `rotate(${_ctx.expanded ? 90 : 0}deg)`,
        }
          }, " ▶ ", 4 /* STYLE */),
          createTextVNode(" " + toDisplayString(_ctx.label) + toDisplayString(" ") + " ", 1 /* TEXT */),
          createVNode("span", { style: { color: 'grey', fontSize: '.7rem' } }, toDisplayString(String(_ctx.type).toLowerCase() === "iterable" ? "(Iterable) " : "") + " " + toDisplayString(_ctx.subEntries.length) + " " + toDisplayString(_ctx.subEntries.length > 1 ? `items` : `item`), 5 /* TEXT, STYLE */)
        ]))
      : createCommentVNode("v-if", true),
    (_ctx.expanded && _ctx.subEntryPages.length === 1)
      ? (openBlock(), createBlock("div", {
          key: 1,
          style: {
        marginLeft: '.1rem',
        paddingLeft: '1rem',
        borderLeft: '2px solid rgba(0,0,0,.15)',
      }
        }, [
          (openBlock(true), createBlock(Fragment, null, renderList(_ctx.subEntries, (entry) => {
            return (openBlock(), createBlock(_component_ExplorerTree, {
              key: entry.label,
              label: entry.label,
              value: entry.value
            }, null, 8 /* PROPS */, ["label", "value"]))
          }), 128 /* KEYED_FRAGMENT */))
        ], 4 /* STYLE */))
      : createCommentVNode("v-if", true),
    (_ctx.expanded && _ctx.subEntryPages.length !== 1)
      ? (openBlock(), createBlock("div", {
          key: 2,
          style: {
        marginLeft: '.1rem',
        paddingLeft: '1rem',
        borderLeft: '2px solid rgba(0,0,0,.15)',
      }
        }, [
          (openBlock(true), createBlock(Fragment, null, renderList(_ctx.subEntryPages, (entries, index) => {
            return (openBlock(), createBlock("div", { key: index }, [
              createVNode("div", { style: {
            fontFamily: 'Menlo, monospace',
            fontSize: '0.9rem',
            lineHeight: '1.7',
            outline: 'none',
            wordBreak: 'break-word',
          } }, [
                createVNode("span", {
                  style: { cursor: 'pointer', color: 'white' },
                  onClick: () => _ctx.setExpandedPages(index)
                }, [
                  createVNode("span", {
                    style: {
                display: 'inline-block',
                transition: 'all .1s ease',
                transform: `rotate(${_ctx.expanded ? 90 : 0}deg)`,
              }
                  }, " ▶ ", 4 /* STYLE */),
                  createTextVNode(" [" + toDisplayString(index * _ctx.pageSize) + " ..." + toDisplayString(" ") + " " + toDisplayString(index * _ctx.pageSize + _ctx.pageSize - 1) + "] ", 1 /* TEXT */)
                ], 8 /* PROPS */, ["onClick"]),
                (_ctx.expandedPages.includes(index))
                  ? (openBlock(), createBlock("div", {
                      key: 0,
                      style: {
              marginLeft: '.1rem',
              paddingLeft: '1rem',
              borderLeft: '2px solid rgba(0,0,0,.15)',
            }
                    }, [
                      (openBlock(true), createBlock(Fragment, null, renderList(entries, (entry) => {
                        return (openBlock(), createBlock(_component_ExplorerTree, {
                          key: entry.label,
                          label: entry.label,
                          value: entry.value
                        }, null, 8 /* PROPS */, ["label", "value"]))
                      }), 128 /* KEYED_FRAGMENT */))
                    ], 4 /* STYLE */))
                  : createCommentVNode("v-if", true)
              ], 4 /* STYLE */)
            ]))
          }), 128 /* KEYED_FRAGMENT */))
        ], 4 /* STYLE */))
      : createCommentVNode("v-if", true),
    (!_ctx.subEntryPages?.length)
      ? (openBlock(), createBlock("span", _hoisted_1$7, toDisplayString(_ctx.label) + ":", 1 /* TEXT */))
      : createCommentVNode("v-if", true),
    _hoisted_2$2,
    (!_ctx.subEntryPages?.length)
      ? (openBlock(), createBlock("span", {
          key: 4,
          style: { color: _ctx.theme.danger }
        }, toDisplayString(JSON.stringify(_ctx.value, Object.getOwnPropertyNames(Object(_ctx.value)))), 5 /* TEXT, STYLE */))
      : createCommentVNode("v-if", true)
  ], 4 /* STYLE */))
}

script$b.render = render$b;
script$b.__file = "src/devtools/components/Explorer.vue";

var script$a = defineComponent({
    name: "InfoPanel",
    props: {
        title: {
            type: String,
            required: true,
        },
    },
    setup() {
        const theme = useTheme();
        return {
            theme,
        };
    },
});

const _withId$8 = /*#__PURE__*/withScopeId("data-v-467d759d");

pushScopeId("data-v-467d759d");
const _hoisted_1$6 = { class: "panel" };
popScopeId();

const render$a = /*#__PURE__*/_withId$8((_ctx, _cache, $props, $setup, $data, $options) => {
  return (openBlock(), createBlock(Fragment, null, [
    createVNode("div", {
      class: "title",
      style: {
      background: _ctx.theme.backgroundAlt,
    }
    }, toDisplayString(_ctx.title), 5 /* TEXT, STYLE */),
    createVNode("div", _hoisted_1$6, [
      renderSlot(_ctx.$slots, "default")
    ])
  ], 64 /* STABLE_FRAGMENT */))
});

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z$8 = "\n.title[data-v-467d759d] {\n  padding: 0.5rem;\n  position: sticky;\n  top: 0;\n  z-index: 1;\n}\n.panel[data-v-467d759d] {\n  padding: 0.5rem;\n}\n";
styleInject(css_248z$8);

script$a.render = render$a;
script$a.__scopeId = "data-v-467d759d";
script$a.__file = "src/devtools/components/InfoPanel.vue";

var script$9 = defineComponent({
    name: "QueryActions",
    components: { InfoPanel: script$a },
    props: {
        query: {
            type: Object,
            required: true,
        },
    },
    setup(props) {
        const theme = useTheme();
        const queryClient = useQueryClient();
        const isFetching = computed(() => props.query.state.isFetching);
        const doFetch = () => {
            props.query.fetch();
        };
        const doInvalidate = () => {
            queryClient.invalidateQueries(props.query);
        };
        const doReset = () => {
            queryClient.resetQueries(props.query);
        };
        const doRemove = () => {
            queryClient.removeQueries(props.query);
        };
        return {
            theme,
            isFetching,
            doFetch,
            doInvalidate,
            doReset,
            doRemove,
        };
    },
});

const _withId$7 = /*#__PURE__*/withScopeId("data-v-65c30cbe");

const render$9 = /*#__PURE__*/_withId$7((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_InfoPanel = resolveComponent("InfoPanel");

  return (openBlock(), createBlock(_component_InfoPanel, { title: "Actions" }, {
    default: _withId$7(() => [
      createVNode("button", {
        type: "button",
        onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.doFetch && _ctx.doFetch(...args))),
        disabled: _ctx.isFetching,
        style: {
        background: _ctx.isFetching ? _ctx.theme.grayAlt : _ctx.theme.active,
        cursor: _ctx.isFetching ? 'not-allowed' : 'pointer',
      }
      }, " Refetch ", 12 /* STYLE, PROPS */, ["disabled"]),
      createVNode("button", {
        type: "button",
        onClick: _cache[2] || (_cache[2] = (...args) => (_ctx.doInvalidate && _ctx.doInvalidate(...args))),
        style: {
        background: _ctx.theme.warning,
        color: _ctx.theme.inputTextColor,
      }
      }, " Invalidate ", 4 /* STYLE */),
      createVNode("button", {
        type: "button",
        onClick: _cache[3] || (_cache[3] = (...args) => (_ctx.doReset && _ctx.doReset(...args))),
        style: {
        background: _ctx.theme.gray,
      }
      }, " Reset ", 4 /* STYLE */),
      createVNode("button", {
        type: "button",
        onClick: _cache[4] || (_cache[4] = (...args) => (_ctx.doRemove && _ctx.doRemove(...args))),
        style: {
        background: _ctx.theme.danger,
      }
      }, " Remove ", 4 /* STYLE */)
    ]),
    _: 1 /* STABLE */
  }))
});

var css_248z$7 = "\nbutton[data-v-65c30cbe] {\n  appearance: none;\n  border-radius: 0.3em;\n  border: 0;\n  color: white;\n  cursor: pointer;\n  font-size: 0.9em;\n  font-weight: bold;\n  padding: 0.5em;\n}\nbutton[data-v-65c30cbe]:not(:last-of-type) {\n  margin-right: 5px;\n}\n";
styleInject(css_248z$7);

script$9.render = render$9;
script$9.__scopeId = "data-v-65c30cbe";
script$9.__file = "src/devtools/components/QueryActions.vue";

var script$8 = defineComponent({
    name: "QueryDetails",
    components: { InfoPanel: script$a },
    props: {
        query: {
            type: Object,
            required: true,
        },
    },
    setup(props) {
        const theme = useTheme();
        const formattedQueryKey = computed(() => props.query.queryHash);
        const queryStatusLabel = computed(() => getQueryStatusLabel(props.query));
        const observersCount = computed(() => props.query.observers.length);
        const updateDate = computed(() => new Date(props.query.state.dataUpdatedAt).toLocaleTimeString());
        const statusBackground = computed(() => getQueryStatusColor(props.query, theme));
        return {
            formattedQueryKey,
            queryStatusLabel,
            observersCount,
            updateDate,
            statusBackground,
        };
    },
});

const _withId$6 = /*#__PURE__*/withScopeId("data-v-e5a8e8fa");

pushScopeId("data-v-e5a8e8fa");
const _hoisted_1$5 = { class: "info-line" };
const _hoisted_2$1 = { class: "info-line" };
const _hoisted_3 = /*#__PURE__*/createTextVNode(" Observers: ");
const _hoisted_4 = { class: "info-line" };
const _hoisted_5 = /*#__PURE__*/createTextVNode(" Last Updated: ");
popScopeId();

const render$8 = /*#__PURE__*/_withId$6((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_InfoPanel = resolveComponent("InfoPanel");

  return (openBlock(), createBlock(_component_InfoPanel, { title: "Query Details" }, {
    default: _withId$6(() => [
      createVNode("div", _hoisted_1$5, [
        createVNode("code", null, [
          createVNode("pre", null, toDisplayString(_ctx.formattedQueryKey), 1 /* TEXT */)
        ]),
        createVNode("span", {
          style: { background: _ctx.statusBackground }
        }, toDisplayString(_ctx.queryStatusLabel), 5 /* TEXT, STYLE */)
      ]),
      createVNode("div", _hoisted_2$1, [
        _hoisted_3,
        createVNode("code", null, toDisplayString(_ctx.observersCount), 1 /* TEXT */)
      ]),
      createVNode("div", _hoisted_4, [
        _hoisted_5,
        createVNode("code", null, toDisplayString(_ctx.updateDate), 1 /* TEXT */)
      ])
    ]),
    _: 1 /* STABLE */
  }))
});

var css_248z$6 = "\n.info-line[data-v-e5a8e8fa] {\n  align-items: stretch;\n  display: flex;\n  justify-content: space-between;\n}\n.info-line[data-v-e5a8e8fa]:not(:last-of-type) {\n  margin-bottom: 0.5rem;\n}\ncode[data-v-e5a8e8fa] {\n  font-size: 0.9em;\n  line-height: 1.8rem;\n}\npre[data-v-e5a8e8fa] {\n  margin: 0;\n  overflow: auto;\n  padding: 0;\n}\nspan[data-v-e5a8e8fa] {\n  border-radius: 0.4rem;\n  flex-shrink: 0;\n  font-weight: bold;\n  padding: 0.3rem 0.6rem;\n  text-shadow: 0 2px 10px black;\n}\n";
styleInject(css_248z$6);

script$8.render = render$8;
script$8.__scopeId = "data-v-e5a8e8fa";
script$8.__file = "src/devtools/components/QueryDetails.vue";

var script$7 = defineComponent({
    name: "ActiveQueryPanel",
    components: { Explorer: script$b, InfoPanel: script$a, QueryActions: script$9, QueryDetails: script$8 },
    props: {
        query: {
            type: Object,
            required: true,
        },
    },
});

const _withId$5 = /*#__PURE__*/withScopeId("data-v-12e7f06b");

pushScopeId("data-v-12e7f06b");
const _hoisted_1$4 = { class: "active-query-panel" };
popScopeId();

const render$7 = /*#__PURE__*/_withId$5((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_QueryDetails = resolveComponent("QueryDetails");
  const _component_QueryActions = resolveComponent("QueryActions");
  const _component_Explorer = resolveComponent("Explorer");
  const _component_InfoPanel = resolveComponent("InfoPanel");

  return (openBlock(), createBlock("div", _hoisted_1$4, [
    createVNode(_component_QueryDetails, { query: _ctx.query }, null, 8 /* PROPS */, ["query"]),
    createVNode(_component_QueryActions, { query: _ctx.query }, null, 8 /* PROPS */, ["query"]),
    createVNode(_component_InfoPanel, { title: "Data Explorer" }, {
      default: _withId$5(() => [
        createVNode(_component_Explorer, {
          label: "Data",
          value: _ctx.query.state.data,
          defaultExpanded: {}
        }, null, 8 /* PROPS */, ["value"])
      ]),
      _: 1 /* STABLE */
    }),
    createVNode(_component_InfoPanel, { title: "Query Explorer" }, {
      default: _withId$5(() => [
        createVNode(_component_Explorer, {
          label: "Query",
          value: _ctx.query,
          defaultExpanded: {
          queryKey: true,
        }
        }, null, 8 /* PROPS */, ["value"])
      ]),
      _: 1 /* STABLE */
    })
  ]))
});

var css_248z$5 = "\n.active-query-panel[data-v-12e7f06b] {\n  display: flex;\n  flex-direction: column;\n  flex: 1 1 500px;\n  height: 100%;\n  overflow: auto;\n}\n";
styleInject(css_248z$5);

script$7.render = render$7;
script$7.__scopeId = "data-v-12e7f06b";
script$7.__file = "src/devtools/components/ActiveQueryPanel.vue";

var script$6 = defineComponent({
    name: "QueryItem",
    props: {
        query: {
            type: Object,
            required: true,
        },
    },
    setup(props, { emit }) {
        const theme = useTheme();
        const observerCount = computed(() => props.query.observers.length);
        const isStale = computed(() => getQueryState(props.query) === QueryState.Stale);
        const stateColor = computed(() => getQueryStatusColor(props.query, theme));
        const onQueryClick = () => {
            emit("selectQuery", props.query.queryHash);
        };
        return {
            theme,
            observerCount,
            isStale,
            stateColor,
            onQueryClick,
        };
    },
});

const _withId$4 = /*#__PURE__*/withScopeId("data-v-77b5dd22");

const render$6 = /*#__PURE__*/_withId$4((_ctx, _cache, $props, $setup, $data, $options) => {
  return (openBlock(), createBlock("div", {
    onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.onQueryClick && _ctx.onQueryClick(...args))),
    style: {
      display: 'flex',
      borderBottom: `solid 1px ${_ctx.theme.grayAlt}`,
      cursor: 'pointer',
    }
  }, [
    createVNode("div", {
      class: "query-state",
      style: {
        background: _ctx.stateColor,
        textShadow: _ctx.isStale ? '0' : '0 0 10px black',
        color: _ctx.isStale ? 'black' : 'white',
      }
    }, toDisplayString(_ctx.observerCount), 5 /* TEXT, STYLE */),
    createVNode("code", null, toDisplayString(_ctx.query.queryHash), 1 /* TEXT */)
  ], 4 /* STYLE */))
});

var css_248z$4 = "\n.query-state[data-v-77b5dd22] {\n  align-items: center;\n  display: flex;\n  flex: 0 0 auto;\n  font-weight: bold;\n  height: 2rem;\n  justify-content: center;\n  width: 2rem;\n}\ncode[data-v-77b5dd22] {\n  font-size: 0.9em;\n  padding: 0.5rem;\n}\n";
styleInject(css_248z$4);

script$6.render = render$6;
script$6.__scopeId = "data-v-77b5dd22";
script$6.__file = "src/devtools/components/QueryItem.vue";

var script$5 = defineComponent({
    name: "QueryOptions",
    emits: {
        optionsChange: (_options) => true,
    },
    setup(_props, { emit }) {
        const theme = useTheme();
        const sorFnKeys = Object.keys(sortFns);
        const sort = ref(sorFnKeys[0]);
        const options = reactive({
            filter: "",
            sortDesc: false,
            sortFn: sortFns["Status > Last Updated"],
        });
        const onInput = (event) => {
            var _a;
            options.filter = (_a = event.target) === null || _a === void 0 ? void 0 : _a.value;
            emit("optionsChange", options);
        };
        const onKeyDown = (event) => {
            if (event.key === "Escape") {
                options.filter = "";
            }
            emit("optionsChange", options);
        };
        const onSortFnChange = (event) => {
            var _a;
            sort.value = (_a = event.target) === null || _a === void 0 ? void 0 : _a.value;
            options.sortFn = sortFns[sort.value];
            emit("optionsChange", options);
        };
        const onSortDescChange = () => {
            options.sortDesc = !options.sortDesc;
            emit("optionsChange", options);
        };
        return {
            theme,
            sorFnKeys,
            sort,
            options,
            onInput,
            onKeyDown,
            onSortFnChange,
            onSortDescChange,
        };
    },
});

const _withId$3 = /*#__PURE__*/withScopeId("data-v-1c00dc42");

pushScopeId("data-v-1c00dc42");
const _hoisted_1$3 = { class: "options-wrapper" };
popScopeId();

const render$5 = /*#__PURE__*/_withId$3((_ctx, _cache, $props, $setup, $data, $options) => {
  return (openBlock(), createBlock("div", _hoisted_1$3, [
    createVNode("input", {
      placeholder: "Filter",
      onInput: _cache[1] || (_cache[1] = (...args) => (_ctx.onInput && _ctx.onInput(...args))),
      onKeydown: _cache[2] || (_cache[2] = (...args) => (_ctx.onKeyDown && _ctx.onKeyDown(...args))),
      value: _ctx.options.filter,
      style: {
        backgroundColor: _ctx.theme.inputBackgroundColor,
        color: _ctx.theme.inputTextColor,
      }
    }, null, 44 /* STYLE, PROPS, HYDRATE_EVENTS */, ["value"]),
    (!_ctx.options.filter)
      ? (openBlock(), createBlock("select", {
          key: 0,
          onChange: _cache[3] || (_cache[3] = (...args) => (_ctx.onSortFnChange && _ctx.onSortFnChange(...args))),
          value: _ctx.sort,
          style: {
        backgroundColor: _ctx.theme.inputBackgroundColor,
        color: _ctx.theme.inputTextColor,
      }
        }, [
          (openBlock(true), createBlock(Fragment, null, renderList(_ctx.sorFnKeys, (key) => {
            return (openBlock(), createBlock("option", {
              key: key,
              value: key
            }, " Sort by " + toDisplayString(key), 9 /* TEXT, PROPS */, ["value"]))
          }), 128 /* KEYED_FRAGMENT */))
        ], 44 /* STYLE, PROPS, HYDRATE_EVENTS */, ["value"]))
      : createCommentVNode("v-if", true),
    (!_ctx.options.filter)
      ? (openBlock(), createBlock("button", {
          key: 1,
          type: "button",
          onClick: _cache[4] || (_cache[4] = (...args) => (_ctx.onSortDescChange && _ctx.onSortDescChange(...args))),
          style: {
        background: _ctx.theme.gray,
      }
        }, toDisplayString(_ctx.options.sortDesc ? "⬇ Desc" : "⬆ Asc"), 5 /* TEXT, STYLE */))
      : createCommentVNode("v-if", true)
  ]))
});

var css_248z$3 = "\n.options-wrapper[data-v-1c00dc42] {\n  align-items: center;\n  display: flex;\n}\ninput[data-v-1c00dc42] {\n  border-radius: 0.2em;\n  border: 0;\n  flex: 1;\n  font-size: 0.9em;\n  line-height: 1.3;\n  margin-right: 0.5rem;\n  padding: 0.3em 0.4em;\n}\nbutton[data-v-1c00dc42] {\n  appearance: none;\n  background: #3f4e60;\n  border-radius: 0.3em;\n  border: 0;\n  color: white;\n  cursor: pointer;\n  font-size: 0.9em;\n  font-weight: bold;\n  padding: 0.3rem 0.4rem;\n}\nselect[data-v-1c00dc42] {\n  --webkit-appearance: none;\n  appearance: none;\n  background-image: url(\"data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' width='100' height='100' fill='%23444444'><polygon points='0,25 100,25 50,75'/></svg>\");\n  background-position: right 0.55em center;\n  background-repeat: no-repeat;\n  background-size: 0.65em auto, 100%;\n  border-radius: 0.2em;\n  border: 0;\n  display: inline-block;\n  flex: 1;\n  font-family: sans-serif;\n  font-size: 0.9em;\n  font-weight: normal;\n  height: auto;\n  line-height: 1.3;\n  margin-right: 0.5rem;\n  min-width: 75;\n  padding: 0.3em 1.5em 0.3em 0.5em;\n}\n";
styleInject(css_248z$3);

script$5.render = render$5;
script$5.__scopeId = "data-v-1c00dc42";
script$5.__file = "src/devtools/components/QueryOptions.vue";

var script$4 = defineComponent({
    name: "QueryStates",
    setup() {
        const theme = useTheme();
        const queries = ref([]);
        const queryClient = useQueryClient();
        const queryCache = queryClient.getQueryCache();
        queryCache.subscribe(() => {
            queries.value = Object.values(queryCache.getAll());
        });
        const getQueryStateData = (state) => {
            const count = queries.value.filter((q) => getQueryState(q) === state)
                .length;
            return {
                label: QueryStateLabel[state],
                opacity: count ? 1 : 0.3,
                count,
            };
        };
        const fresh = computed(() => getQueryStateData(QueryState.Fresh));
        const fetching = computed(() => getQueryStateData(QueryState.Fetching));
        const stale = computed(() => getQueryStateData(QueryState.Stale));
        const inactive = computed(() => getQueryStateData(QueryState.Inactive));
        return {
            theme,
            fresh,
            fetching,
            stale,
            inactive,
        };
    },
});

const _withId$2 = /*#__PURE__*/withScopeId("data-v-1ce8bed1");

pushScopeId("data-v-1ce8bed1");
const _hoisted_1$2 = { class: "query-states" };
popScopeId();

const render$4 = /*#__PURE__*/_withId$2((_ctx, _cache, $props, $setup, $data, $options) => {
  return (openBlock(), createBlock("span", _hoisted_1$2, [
    createVNode("span", {
      class: "query-state",
      style: {
        background: _ctx.theme.success,
        opacity: _ctx.fresh.opacity,
      }
    }, toDisplayString(_ctx.fresh.label) + " " + toDisplayString(_ctx.fresh.count), 5 /* TEXT, STYLE */),
    createVNode("span", {
      class: "query-state",
      style: {
        background: _ctx.theme.active,
        opacity: _ctx.fetching.opacity,
      }
    }, toDisplayString(_ctx.fetching.label) + " " + toDisplayString(_ctx.fetching.count), 5 /* TEXT, STYLE */),
    createVNode("span", {
      class: "query-state",
      style: {
        background: _ctx.theme.warning,
        color: 'black',
        textShadow: '0',
        opacity: _ctx.stale.opacity,
      }
    }, toDisplayString(_ctx.stale.label) + " " + toDisplayString(_ctx.stale.count), 5 /* TEXT, STYLE */),
    createVNode("span", {
      class: "query-state",
      style: {
        background: _ctx.theme.gray,
        opacity: _ctx.inactive.opacity,
      }
    }, toDisplayString(_ctx.inactive.label) + " " + toDisplayString(_ctx.inactive.count), 5 /* TEXT, STYLE */)
  ]))
});

var css_248z$2 = "\n.query-states[data-v-1ce8bed1] {\n  display: flex;\n  font-size: 0.9em;\n  justify-content: flex-end;\n  margin-bottom: 0.5rem;\n}\n.query-state[data-v-1ce8bed1] {\n  align-items: center;\n  border-radius: 0.2em;\n  display: inline-flex;\n  font-weight: bold;\n  margin-left: 5px;\n  padding: 0.2em 0.4em;\n  text-shadow: 0 0 10px black;\n}\n";
styleInject(css_248z$2);

script$4.render = render$4;
script$4.__scopeId = "data-v-1ce8bed1";
script$4.__file = "src/devtools/components/QueryStates.vue";

var script$3 = defineComponent({
    name: "DevtoolsPanel",
    components: { Logo: script$c, ActiveQueryPanel: script$7, QueryItem: script$6, QueryOptions: script$5, QueryStates: script$4 },
    props: {
        isOpen: {
            type: Boolean,
            required: true,
        },
        panelProps: {
            type: Object,
            default: {},
        },
    },
    setup(props, { emit }) {
        const theme = useTheme();
        const devtoolsPanelStyles = computed(() => ({
            backgroundColor: theme.background,
            color: theme.foreground,
        }));
        const options = reactive({
            filter: "",
            sortDesc: false,
            sortFn: sortFns["Status > Last Updated"],
        });
        const onOptionsChange = (newOptions) => {
            Object.assign(options, newOptions);
        };
        const queries = ref([]);
        const getSortedQueries = () => {
            const queries = queryCache.getAll();
            const sorted = [...queries].sort(options.sortFn);
            if (options.sortDesc) {
                sorted.reverse();
            }
            if (!options.filter) {
                return sorted;
            }
            return matchSorter(sorted, options.filter, {
                keys: ["queryHash"],
            }).filter((d) => d.queryHash);
        };
        const queryClient = useQueryClient();
        const queryCache = queryClient.getQueryCache();
        queryCache.subscribe(() => {
            queries.value = getSortedQueries();
        });
        const activeQuery = ref();
        const selectQuery = (queryHash) => {
            var _a;
            if (((_a = activeQuery.value) === null || _a === void 0 ? void 0 : _a.queryHash) === queryHash) {
                activeQuery.value = undefined;
            }
            else {
                activeQuery.value = queryCache.get(queryHash);
            }
        };
        const handleDragStart = (event) => {
            emit("handleDragStart", event);
        };
        return {
            theme,
            devtoolsPanelStyles,
            queries,
            getQueryState,
            onOptionsChange,
            activeQuery,
            selectQuery,
            handleDragStart,
        };
    },
});

const _withId$1 = /*#__PURE__*/withScopeId("data-v-6c1bb3ce");

pushScopeId("data-v-6c1bb3ce");
const _hoisted_1$1 = { style: {
            display: 'flex',
            flexDirection: 'column',
          } };
const _hoisted_2 = { class: "query-list" };
popScopeId();

const render$3 = /*#__PURE__*/_withId$1((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_Logo = resolveComponent("Logo");
  const _component_QueryStates = resolveComponent("QueryStates");
  const _component_QueryOptions = resolveComponent("QueryOptions");
  const _component_QueryItem = resolveComponent("QueryItem");
  const _component_ActiveQueryPanel = resolveComponent("ActiveQueryPanel");

  return (openBlock(), createBlock("div", {
    class: "VueQueryDevtoolsPanel",
    style: _ctx.devtoolsPanelStyles
  }, [
    createVNode("div", {
      class: "resize-bar",
      onMousedown: _cache[1] || (_cache[1] = (...args) => (_ctx.handleDragStart && _ctx.handleDragStart(...args)))
    }, null, 32 /* HYDRATE_EVENTS */),
    createVNode("div", {
      class: "query-panel",
      style: {
        borderRight: `1px solid ${_ctx.theme.grayAlt}`,
      }
    }, [
      createVNode("div", {
        class: "query-panel-header",
        style: {
          background: _ctx.theme.backgroundAlt,
        }
      }, [
        createVNode(_component_Logo, {
          "aria-hidden": "",
          style: {
            marginRight: '.5rem',
          }
        }, null, 8 /* PROPS */, ["style"]),
        createVNode("div", _hoisted_1$1, [
          createVNode(_component_QueryStates),
          createVNode(_component_QueryOptions, { onOptionsChange: _ctx.onOptionsChange }, null, 8 /* PROPS */, ["onOptionsChange"])
        ])
      ], 4 /* STYLE */),
      createVNode("div", _hoisted_2, [
        (openBlock(true), createBlock(Fragment, null, renderList(_ctx.queries, (query) => {
          return (openBlock(), createBlock(_component_QueryItem, {
            onSelectQuery: _ctx.selectQuery,
            key: _ctx.getQueryState(query) + query.state.dataUpdatedAt,
            query: query,
            style: {
            background:
              query === _ctx.activeQuery ? 'rgba(255,255,255,.1)' : undefined,
          }
          }, null, 8 /* PROPS */, ["onSelectQuery", "query", "style"]))
        }), 128 /* KEYED_FRAGMENT */))
      ])
    ], 4 /* STYLE */),
    (_ctx.activeQuery)
      ? (openBlock(), createBlock(_component_ActiveQueryPanel, {
          key: _ctx.getQueryState(_ctx.activeQuery) + _ctx.activeQuery.state.dataUpdatedAt,
          query: _ctx.activeQuery
        }, null, 8 /* PROPS */, ["query"]))
      : createCommentVNode("v-if", true)
  ], 4 /* STYLE */))
});

var css_248z$1 = "\n.VueQueryDevtoolsPanel[data-v-6c1bb3ce] {\n  display: flex;\n  font-family: sans-serif;\n  font-size: clamp(12px, 1.5vw, 14px);\n}\n@media (max-width: 1000px) {\n.VueQueryDevtoolsPanel[data-v-6c1bb3ce] {\n    flex-direction: column;\n}\n}\n@media (max-width: 600px) {\n.VueQueryDevtoolsPanel[data-v-6c1bb3ce] {\n    font-size: 0.9rem;\n}\n}\n.resize-bar[data-v-6c1bb3ce] {\n  cursor: row-resize;\n  height: 4px;\n  left: 0;\n  margin-bottom: -4px;\n  position: absolute;\n  top: 0;\n  width: 100%;\n  z-index: 100000;\n}\n.query-panel[data-v-6c1bb3ce] {\n  display: flex;\n  flex-direction: column;\n  flex: 1 1 500px;\n  max-height: 100%;\n  min-height: 40%;\n  overflow: auto;\n}\n.query-panel-header[data-v-6c1bb3ce] {\n  align-items: center;\n  display: flex;\n  justify-content: space-between;\n  padding: 0.5rem;\n}\n.query-list[data-v-6c1bb3ce] {\n  flex: 1;\n  overflow-y: auto;\n}\n";
styleInject(css_248z$1);

script$3.render = render$3;
script$3.__scopeId = "data-v-6c1bb3ce";
script$3.__file = "src/devtools/DevtoolsPanel.vue";

var script$2 = defineComponent({
    name: "CloseButton",
    props: {
        position: {
            type: String,
            required: true,
        },
        buttonProps: {
            type: Object,
            default: {},
        },
    },
    emits: ["click"],
    setup(props, context) {
        const onClick = () => {
            var _a, _b;
            context.emit("click");
            (_b = (_a = props.buttonProps).click) === null || _b === void 0 ? void 0 : _b.call(_a);
        };
        const position = computed(() => {
            if (props.position === Position.TR || props.position === Position.BR) {
                return { right: 0 };
            }
            return { left: 0 };
        });
        const buttonStyles = computed(() => (Object.assign(Object.assign({ position: "fixed", zIndex: "99999", margin: ".5rem", bottom: 0 }, position.value), props.buttonProps.style)));
        return {
            onClick,
            buttonStyles,
        };
    },
});

function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("button", {
    type: "button",
    onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.onClick && _ctx.onClick(...args))),
    style: _ctx.buttonStyles
  }, "Close", 4 /* STYLE */))
}

script$2.render = render$2;
script$2.__file = "src/devtools/components/CloseButton.vue";

var script$1 = defineComponent({
    name: "ToggleButton",
    components: { Logo: script$c },
    props: {
        position: {
            type: String,
            required: true,
        },
        buttonProps: {
            type: Object,
            default: {},
        },
    },
    emits: ["click"],
    setup(props, context) {
        const onClick = () => {
            var _a, _b;
            context.emit("click");
            (_b = (_a = props.buttonProps).click) === null || _b === void 0 ? void 0 : _b.call(_a);
        };
        const position = computed(() => {
            if (props.position === Position.TR) {
                return { top: 0, right: 0 };
            }
            if (props.position === Position.TL) {
                return { top: 0, left: 0 };
            }
            if (props.position === Position.BR) {
                return { bottom: 0, right: 0 };
            }
            return { bottom: 0, left: 0 };
        });
        const buttonStyles = computed(() => (Object.assign(Object.assign({ background: "none", border: 0, padding: 0, position: "fixed", zIndex: "99999", display: "inline-flex", fontSize: "1.5rem", margin: ".5rem", cursor: "pointer", width: "fit-content" }, position.value), props.buttonProps.style)));
        return {
            onClick,
            buttonStyles,
        };
    },
});

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_logo = resolveComponent("logo");

  return (openBlock(), createBlock("button", {
    type: "button",
    "aria-label": "Open Vue Query Devtools",
    onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.onClick && _ctx.onClick(...args))),
    style: _ctx.buttonStyles
  }, [
    createVNode(_component_logo)
  ], 4 /* STYLE */))
}

script$1.render = render$1;
script$1.__file = "src/devtools/components/ToggleButton.vue";

var script = defineComponent({
    name: "VueQueryDevTools",
    components: { CloseButton: script$2, DevtoolsPanel: script$3, ToggleButton: script$1 },
    props: {
        initialIsOpen: {
            type: Boolean,
            default: false,
        },
        panelProps: {
            type: Object,
            default: {},
        },
        closeButtonProps: {
            type: Object,
            default: {},
        },
        toggleButtonProps: {
            type: Object,
            default: {},
        },
        position: {
            type: String,
            default: Position.BL,
        },
        containerElement: {
            type: String,
            default: "footer",
        },
    },
    setup(props) {
        const isOpen = ref(props.initialIsOpen);
        const isResizing = ref(false);
        const devtoolsHeight = ref("500px");
        const panelRef = ref();
        const onToggleClick = () => {
            isOpen.value = !isOpen.value;
        };
        const handleDragStart = (event) => {
            var _a;
            console.log("drag start", panelRef.value);
            if (event.button !== 0)
                return;
            isResizing.value = true;
            const dragInfo = {
                originalHeight: (_a = panelRef.value) === null || _a === void 0 ? void 0 : _a.$el.getBoundingClientRect().height,
                pageY: event.pageY,
            };
            const run = (moveEvent) => {
                const delta = dragInfo.pageY - moveEvent.pageY;
                const newHeight = dragInfo.originalHeight + delta;
                devtoolsHeight.value = newHeight + "px";
                if (newHeight < 100) {
                    isOpen.value = false;
                }
                else {
                    isOpen.value = true;
                }
            };
            const unsub = () => {
                isResizing.value = false;
                document.removeEventListener("mousemove", run);
                document.removeEventListener("mouseUp", unsub);
            };
            document.addEventListener("mousemove", run);
            document.addEventListener("mouseup", unsub);
        };
        return {
            isOpen,
            isResizing,
            devtoolsHeight,
            panelRef,
            onToggleClick,
            handleDragStart,
        };
    },
});

const _withId = /*#__PURE__*/withScopeId("data-v-8beda3f4");

pushScopeId("data-v-8beda3f4");
const _hoisted_1 = { class: "VueQueryDevtools" };
popScopeId();

const render = /*#__PURE__*/_withId((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_DevtoolsPanel = resolveComponent("DevtoolsPanel");
  const _component_CloseButton = resolveComponent("CloseButton");
  const _component_ToggleButton = resolveComponent("ToggleButton");

  return (openBlock(), createBlock("div", _hoisted_1, [
    createVNode(_component_DevtoolsPanel, {
      class: ["devtools-panel", { resizing: _ctx.isResizing, open: _ctx.isOpen }],
      ref: "panelRef",
      onHandleDragStart: _ctx.handleDragStart,
      style: {
        height: _ctx.devtoolsHeight,
      },
      isOpen: _ctx.isOpen,
      panelProps: _ctx.panelProps
    }, null, 8 /* PROPS */, ["onHandleDragStart", "class", "style", "isOpen", "panelProps"]),
    (_ctx.isOpen)
      ? (openBlock(), createBlock(_component_CloseButton, {
          key: 0,
          position: _ctx.position,
          buttonProps: _ctx.closeButtonProps,
          onClick: _ctx.onToggleClick
        }, null, 8 /* PROPS */, ["position", "buttonProps", "onClick"]))
      : createCommentVNode("v-if", true),
    (!_ctx.isOpen)
      ? (openBlock(), createBlock(_component_ToggleButton, {
          key: 1,
          position: _ctx.position,
          buttonProps: _ctx.toggleButtonProps,
          onClick: _ctx.onToggleClick
        }, null, 8 /* PROPS */, ["position", "buttonProps", "onClick"]))
      : createCommentVNode("v-if", true)
  ]))
});

var css_248z = "\n.devtools-panel[data-v-8beda3f4] {\n  bottom: 0;\n  box-shadow: 0 0 20px rgba(0, 0, 0, 0.3);\n  max-height: 90%;\n  opacity: 0;\n  pointer-events: none;\n  position: fixed;\n  right: 0;\n  transform-origin: top;\n  transform: translateY(15px) scale(1.02);\n  transition: all 0.2s ease;\n  width: 100%;\n  z-index: 99999;\n}\n.resizing[data-v-8beda3f4] {\n  transition: none;\n}\n.open[data-v-8beda3f4] {\n  opacity: 1;\n  pointer-events: all;\n  transform: translateY(0) scale(1);\n}\n";
styleInject(css_248z);

script.render = render;
script.__scopeId = "data-v-8beda3f4";
script.__file = "src/devtools/Devtools.vue";

export { VUE_QUERY_DEVTOOLS_THEME, script as VueQueryDevTools, script$3 as VueQueryDevToolsPanel };
//# sourceMappingURL=devtools-bundle.js.map
